==> index_now-1.0.8.tar.gz: index_now/src/PathAliasOperations.php <==
<?php

namespace Drupal\index_now;

use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\path_alias\Entity\PathAlias;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Path alias operations class.
 */
class PathAliasOperations implements ContainerInjectionInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The class resolver service.
   *
   * @var \Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  protected $classResolver;

  /**
   * Node operations class constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $class_resolver
   *   The class resolver service.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    ClassResolverInterface $class_resolver
  ) {
    $this->entityTypeManager = $entity_type_manager;
    $this->classResolver = $class_resolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('class_resolver')
    );
  }

  /**
   * Ping Index Now for the given path alias.
   *
   * @param \Drupal\path_alias\Entity\PathAlias $path_alias
   *   The path alias we want to ping.
   */
  public function pingIndexNow(PathAlias $path_alias) {
    $exploded_path = explode('/', $path_alias->getPath());
    $entity_type = $exploded_path[1];
    $entity_id = $exploded_path[2];

    $entity_storage = $this->entityTypeManager->getStorage($entity_type);
    if (!$entity_storage) {
      return;
    }
    $entity = $entity_storage->load($entity_id);
    if (!$entity) {
      return;
    }

    switch ($entity_type) {
      case 'node':
        $this->classResolver
          ->getInstanceFromDefinition(NodeOperations::class)
          ->pingIndexNow($entity);
        break;

      case 'taxonomy_term':
        $this->classResolver
          ->getInstanceFromDefinition(TermOperations::class)
          ->pingIndexNow($entity);
        break;

      case 'commerce_product':
        $this->classResolver
          ->getInstanceFromDefinition(CommerceProductOperations::class)
          ->pingIndexNow($entity);
        break;
    }
  }

}

==> index_now-1.0.9.tar.gz: index_now/src/PathAliasOperations.php <==
<?php

namespace Drupal\index_now;

use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Path\PathValidatorInterface;
use Drupal\path_alias\Entity\PathAlias;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Path alias operations class.
 */
class PathAliasOperations implements ContainerInjectionInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The class resolver service.
   *
   * @var \Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  protected $classResolver;

  /**
   * The path validator service.
   *
   * @var \Drupal\Core\Path\PathValidatorInterface
   */
  protected $pathValidator;

  /**
   * Node operations class constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $class_resolver
   *   The class resolver service.
   * @param \Drupal\Core\Path\PathValidatorInterface $path_validator
   *   The path validator service.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    ClassResolverInterface $class_resolver,
    PathValidatorInterface $path_validator
  ) {
    $this->entityTypeManager = $entity_type_manager;
    $this->classResolver = $class_resolver;
    $this->pathValidator = $path_validator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('class_resolver'),
      $container->get('path.validator')
    );
  }

  /**
   * Ping Index Now for the given path alias.
   *
   * @param \Drupal\path_alias\Entity\PathAlias $path_alias
   *   The path alias we want to ping.
   */
  public function pingIndexNow(PathAlias $path_alias) {
    $type_and_id = $this->getEntityTypeAndIdFromPath($path_alias->getPath());
    $entity_type = $type_and_id['entity_type'];
    $entity_id = $type_and_id['entity_id'];

    $entity_storage = $this->entityTypeManager->getStorage($entity_type);
    if (!$entity_storage) {
      return;
    }
    $entity = $entity_storage->load($entity_id);
    if (!$entity) {
      return;
    }

    switch ($entity_type) {
      case 'node':
        $this->classResolver
          ->getInstanceFromDefinition(NodeOperations::class)
          ->pingIndexNow($entity);
        break;

      case 'taxonomy_term':
        $this->classResolver
          ->getInstanceFromDefinition(TermOperations::class)
          ->pingIndexNow($entity);
        break;

      case 'commerce_product':
        $this->classResolver
          ->getInstanceFromDefinition(CommerceProductOperations::class)
          ->pingIndexNow($entity);
        break;
    }
  }

  /**
   * Get the entity type and ID from a path.
   *
   * @param string $path
   *   The path we want to get the entity type and ID from.
   *
   * @return array
   *   An array containing the entity type and ID.
   */
  public function getEntityTypeAndIdFromPath(string $path) {
    $result = ['entity_type' => NULL, 'entity_id' => NULL];
    $url = $this->pathValidator->getUrlIfValid($path);
    if ($url && $url->isRouted()) {
      $route_parameters = $url->getRouteParameters();
      foreach ($route_parameters as $entity_type => $id) {
        if (is_numeric($id) && $this->entityTypeManager->hasDefinition($entity_type)) {
          $result['entity_type'] = $entity_type;
          $result['entity_id'] = $id;
          break;
        }
      }
    }

    return $result;
  }

}
